/*
 * DPAPRecord factory class
 *
 * Copyright (C) 2008 W. Michael Petullo <mike@flyn.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "util.h"
#include "dmapd-dpap-record.h"
#include "dmapd-dpap-record-factory.h"

DMAPRecord *
dmapd_dpap_record_factory_create  (DMAPRecordFactory *factory, const char *path)
{
	DmapdDPAPRecord *record = NULL;
	GByteArray *blob;

	blob = cache_read (path);

	if (blob) {
		record = dmapd_dpap_record_new_from_blob (blob);
		g_byte_array_free (blob, TRUE);
	} else {
		size_t size;
		record = dmapd_dpap_record_new (path);
		if (record != NULL) {
			blob = dmapd_dpap_record_to_blob (record, &size);
			cache_store (path, blob, size);
			g_byte_array_free (blob, TRUE);
		}
	}

	return DMAP_RECORD (record);
}

static void
dmapd_dpap_record_factory_init (DmapdDPAPRecordFactory *factory)
{
}

static void
dmapd_dpap_record_factory_class_init (DmapdDPAPRecordFactoryClass *klass)
{
}

static void
dmapd_dpap_record_factory_interface_init (gpointer iface, gpointer data)
{
	DMAPRecordFactoryInterface *factory = iface;

	g_assert (G_TYPE_FROM_INTERFACE (factory) == TYPE_DMAP_RECORD_FACTORY);

	factory->create = dmapd_dpap_record_factory_create;
}

G_DEFINE_TYPE_WITH_CODE (DmapdDPAPRecordFactory, dmapd_dpap_record_factory, G_TYPE_OBJECT, 
			 G_IMPLEMENT_INTERFACE (TYPE_DMAP_RECORD_FACTORY,
					        dmapd_dpap_record_factory_interface_init))

DmapdDPAPRecordFactory *
dmapd_dpap_record_factory_new (void)
{
	DmapdDPAPRecordFactory *factory;

	factory = DMAPD_DPAP_RECORD_FACTORY (g_object_new (TYPE_DMAPD_DPAP_RECORD_FACTORY, NULL));

	return factory;
}
