/*
 *  Interface for a GGstInputStream factory
 *
 *  Copyright (C) 2008 W. Michael Petullo <mike@flyn.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "g-gst-input-stream-factory.h"

static gint g_gst_input_stream_factory_init_count = 0;

static void
g_gst_input_stream_factory_init (GGstInputStreamFactoryInterface *iface)
{
	g_gst_input_stream_factory_init_count++;
}

static void
g_gst_input_stream_factory_finalize (GGstInputStreamFactoryInterface *iface)
{
	g_gst_input_stream_factory_init_count--;
}

/* FIXME: No G_DEFINE_INTERFACE available in GObject headers: */
GType
g_gst_input_stream_factory_get_type (void)
{
	static GType object_type = 0;
	if (!object_type) {
		static const GTypeInfo object_info = {
			sizeof(GGstInputStreamFactoryInterface),
			(GBaseInitFunc) g_gst_input_stream_factory_init,
			(GBaseFinalizeFunc) g_gst_input_stream_factory_finalize
		};
		object_type =
		    g_type_register_static(G_TYPE_INTERFACE,
					   "GGstInputStreamFactory",
					   &object_info, 0);
	}
	return object_type;
}

GGstInputStream *
g_gst_input_stream_factory_create (GGstInputStreamFactory *factory, const char *location)
{
	return G_GST_INPUT_STREAM_FACTORY_GET_INTERFACE (factory)->create (factory, location);
}
